==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/GetOutcome.java <==
package de.fzj.unicore.ucc.actions;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStreamReader;

import de.fzj.unicore.ucc.runner.Runner;
import de.fzj.unicore.ucc.util.Builder;
import de.fzj.unicore.wsrflite.xmlbeans.WSUtilities;

public class GetOutcome extends Run {

	protected void initBuilder(){
		String arg=null;
		if(getCommandLine().getArgs().length>1)arg=getCommandLine().getArgs()[1];
		String url=null;
		if(arg==null){
			try{
				url=new BufferedReader(new InputStreamReader(System.in)).readLine();
			}catch(Exception e){
				System.err.println("Can't read job EPR from stdin.");
				endProcessing(ERROR_CLIENT);
			}
		}
		else{
			initFromCmdline(arg);
			url=builder.getProperty("epr");
			if(url==null){
				System.err.println("Job EPR not found! Maybe <"+arg+"> has not been produced by ucc.");
				endProcessing(ERROR_CLIENT);
			}
		}
	}
	
	private void initFromCmdline(String arg){
		try{
			File job=new File(arg);
			if(job.exists())
			{
				builder=new Builder(job);
				verbose("Read job from <"+arg+">");
			}
			else{
				verbose("Accessing job at EPR = <"+arg+">");
				builder=new Builder();
				builder.setProperty("epr", arg);
				builder.setProperty("id", WSUtilities.extractResourceID(arg));
			}
		}catch(Exception e){
			error("Can't use <"+arg+">.",e);
			endProcessing(ERROR_CLIENT);
		}
				
	}

	@Override
	public String getName(){
		return "get-output";
	}

	@Override
	public String getArgumentList(){
		return "[<jobfile> | <jobepr>]";
	}
	
	@Override
	public String getSynopsis(){
		return "Gets the output of a UNICORE 6 job. " +
				"The job is referenced either by a job file as written " +
				"by the run-job command or as an EPR.";
	}
	
	@Override
	public String getDescription(){
		return "get output files";
	}

	@Override
	public String getCommandGroup(){
		return "Job execution";
	}

	@Override
	protected void run(){
		try{
			builder.setProperty("state", Runner.STARTED);
			builder.setProperty("Output",output.getAbsolutePath());
			builder.setProperty("IDLocation",output.getAbsolutePath());
			runner=new Runner(registry,securityProperties,builder);
			runner.setBriefOutfileNames(brief);
			runner.setProperties(properties);
			runner.run();
		}
		catch(Exception e){
			error("Error getting output", e);
			endProcessing(ERROR);
		}
	}
}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/GetOutcome.java <==
package de.fzj.unicore.ucc.actions;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStreamReader;

import de.fzj.unicore.ucc.runner.Runner;
import de.fzj.unicore.ucc.util.Builder;
import de.fzj.unicore.wsrflite.xmlbeans.WSUtilities;

public class GetOutcome extends Run {

	@Override
	protected void initBuilder(String arg){
		try{
			File job=new File(arg);
			if(job.exists())
			{
				builder=new Builder(job);
				builder.setCheckLocalFiles(false);
				verbose("Read job from <"+arg+">");
			}
			else{
				verbose("Accessing job at EPR = <"+arg+">");
				builder=new Builder();
				builder.setCheckLocalFiles(false);
				builder.setProperty("epr", arg);
				builder.setProperty("id", WSUtilities.extractResourceID(arg));
			}
		}catch(Exception e){
			error("Can't use <"+arg+">.",e);
			endProcessing(ERROR_CLIENT);
		}
	}
	
	@Override
	protected void initBuilderFromStdin(){
		String arg=null;
		try{
			arg=new BufferedReader(new InputStreamReader(System.in)).readLine();
			initBuilder(arg);
		}catch(Exception e){
			System.err.println("Can't read job EPR from stdin.");
			endProcessing(ERROR_CLIENT);
		}
	}

	@Override
	public String getName(){
		return "get-output";
	}

	@Override
	public String getArgumentList(){
		return "[<jobfile> | <jobepr>]";
	}
	
	@Override
	public String getSynopsis(){
		return "Gets the output of a UNICORE 6 job. " +
				"The job is referenced either by a job file as written " +
				"by the run-job command or as an EPR.";
	}
	
	@Override
	public String getDescription(){
		return "get output files";
	}

	@Override
	public String getCommandGroup(){
		return "Job execution";
	}

	@Override
	protected void run(){
		try{
			builder.setProperty("state", Runner.STARTED);
			builder.setProperty("Output",output.getAbsolutePath());
			builder.setProperty("IDLocation",output.getAbsolutePath());
			runner=new Runner(registry,securityProperties,builder);
			runner.setBriefOutfileNames(brief);
			runner.setProperties(properties);
			runner.run();
		}
		catch(Exception e){
			error("Error getting output", e);
			endProcessing(ERROR);
		}
	}
}
